@@ -118,7 +118,7 @@ def html_board(vulnerable, dealer):
     elif vulnerable == "EW":
         all["ew_vulnerable"]= VULNERABLE_COLOR
         all["ns_vulnerable"]= NONE_COLOR
-    elif vulnerable == "NONE":
+    elif vulnerable.upper() == "NONE":
         all["ew_vulnerable"]= NONE_COLOR
         all["ns_vulnerable"]= NONE_COLOR
     else:
